# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayCreateMigration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_1password_email': 'str',
        '_1password_password': 'str',
        '_1password_secret_key': 'str',
        '_1password_url': 'str',
        '_1password_vaults': 'list[str]',
        'ad_auto_rotate': 'str',
        'ad_computer_base_dn': 'str',
        'ad_discover_local_users': 'str',
        'ad_domain_name': 'str',
        'ad_domain_users_path_template': 'str',
        'ad_local_users_ignore': 'str',
        'ad_local_users_path_template': 'str',
        'ad_rotation_hour': 'int',
        'ad_rotation_interval': 'int',
        'ad_sra_enable_rdp': 'str',
        'ad_target_name': 'str',
        'ad_targets_path_template': 'str',
        'ad_user_base_dn': 'str',
        'ad_user_groups': 'str',
        'as_ssh_port': 'str',
        'aws_key': 'str',
        'aws_key_id': 'str',
        'aws_region': 'str',
        'azure_client_id': 'str',
        'azure_kv_name': 'str',
        'azure_secret': 'str',
        'azure_tenant_id': 'str',
        'gcp_key': 'str',
        'hashi_json': 'str',
        'hashi_ns': 'list[str]',
        'hashi_token': 'str',
        'hashi_url': 'str',
        'json': 'bool',
        'k8s_ca_certificate': 'list[int]',
        'k8s_client_certificate': 'list[int]',
        'k8s_client_key': 'list[int]',
        'k8s_namespace': 'str',
        'k8s_password': 'str',
        'k8s_skip_system': 'bool',
        'k8s_token': 'str',
        'k8s_url': 'str',
        'k8s_username': 'str',
        'name': 'str',
        'protection_key': 'str',
        'target_location': 'str',
        'token': 'str',
        'type': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        '_1password_email': '1password-email',
        '_1password_password': '1password-password',
        '_1password_secret_key': '1password-secret-key',
        '_1password_url': '1password-url',
        '_1password_vaults': '1password-vaults',
        'ad_auto_rotate': 'ad_auto_rotate',
        'ad_computer_base_dn': 'ad_computer_base_dn',
        'ad_discover_local_users': 'ad_discover_local_users',
        'ad_domain_name': 'ad_domain_name',
        'ad_domain_users_path_template': 'ad_domain_users_path_template',
        'ad_local_users_ignore': 'ad_local_users_ignore',
        'ad_local_users_path_template': 'ad_local_users_path_template',
        'ad_rotation_hour': 'ad_rotation_hour',
        'ad_rotation_interval': 'ad_rotation_interval',
        'ad_sra_enable_rdp': 'ad_sra_enable_rdp',
        'ad_target_name': 'ad_target_name',
        'ad_targets_path_template': 'ad_targets_path_template',
        'ad_user_base_dn': 'ad_user_base_dn',
        'ad_user_groups': 'ad_user_groups',
        'as_ssh_port': 'as_ssh_port',
        'aws_key': 'aws-key',
        'aws_key_id': 'aws-key-id',
        'aws_region': 'aws-region',
        'azure_client_id': 'azure-client-id',
        'azure_kv_name': 'azure-kv-name',
        'azure_secret': 'azure-secret',
        'azure_tenant_id': 'azure-tenant-id',
        'gcp_key': 'gcp-key',
        'hashi_json': 'hashi-json',
        'hashi_ns': 'hashi-ns',
        'hashi_token': 'hashi-token',
        'hashi_url': 'hashi-url',
        'json': 'json',
        'k8s_ca_certificate': 'k8s-ca-certificate',
        'k8s_client_certificate': 'k8s-client-certificate',
        'k8s_client_key': 'k8s-client-key',
        'k8s_namespace': 'k8s-namespace',
        'k8s_password': 'k8s-password',
        'k8s_skip_system': 'k8s-skip-system',
        'k8s_token': 'k8s-token',
        'k8s_url': 'k8s-url',
        'k8s_username': 'k8s-username',
        'name': 'name',
        'protection_key': 'protection-key',
        'target_location': 'target-location',
        'token': 'token',
        'type': 'type',
        'uid_token': 'uid-token'
    }

    def __init__(self, _1password_email=None, _1password_password=None, _1password_secret_key=None, _1password_url=None, _1password_vaults=None, ad_auto_rotate=None, ad_computer_base_dn=None, ad_discover_local_users=None, ad_domain_name=None, ad_domain_users_path_template=None, ad_local_users_ignore=None, ad_local_users_path_template=None, ad_rotation_hour=None, ad_rotation_interval=None, ad_sra_enable_rdp=None, ad_target_name=None, ad_targets_path_template=None, ad_user_base_dn=None, ad_user_groups=None, as_ssh_port=None, aws_key=None, aws_key_id=None, aws_region=None, azure_client_id=None, azure_kv_name=None, azure_secret=None, azure_tenant_id=None, gcp_key=None, hashi_json=None, hashi_ns=None, hashi_token=None, hashi_url=None, json=None, k8s_ca_certificate=None, k8s_client_certificate=None, k8s_client_key=None, k8s_namespace=None, k8s_password=None, k8s_skip_system=None, k8s_token=None, k8s_url=None, k8s_username=None, name=None, protection_key=None, target_location=None, token=None, type=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """GatewayCreateMigration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__1password_email = None
        self.__1password_password = None
        self.__1password_secret_key = None
        self.__1password_url = None
        self.__1password_vaults = None
        self._ad_auto_rotate = None
        self._ad_computer_base_dn = None
        self._ad_discover_local_users = None
        self._ad_domain_name = None
        self._ad_domain_users_path_template = None
        self._ad_local_users_ignore = None
        self._ad_local_users_path_template = None
        self._ad_rotation_hour = None
        self._ad_rotation_interval = None
        self._ad_sra_enable_rdp = None
        self._ad_target_name = None
        self._ad_targets_path_template = None
        self._ad_user_base_dn = None
        self._ad_user_groups = None
        self._as_ssh_port = None
        self._aws_key = None
        self._aws_key_id = None
        self._aws_region = None
        self._azure_client_id = None
        self._azure_kv_name = None
        self._azure_secret = None
        self._azure_tenant_id = None
        self._gcp_key = None
        self._hashi_json = None
        self._hashi_ns = None
        self._hashi_token = None
        self._hashi_url = None
        self._json = None
        self._k8s_ca_certificate = None
        self._k8s_client_certificate = None
        self._k8s_client_key = None
        self._k8s_namespace = None
        self._k8s_password = None
        self._k8s_skip_system = None
        self._k8s_token = None
        self._k8s_url = None
        self._k8s_username = None
        self._name = None
        self._protection_key = None
        self._target_location = None
        self._token = None
        self._type = None
        self._uid_token = None
        self.discriminator = None

        if _1password_email is not None:
            self._1password_email = _1password_email
        if _1password_password is not None:
            self._1password_password = _1password_password
        if _1password_secret_key is not None:
            self._1password_secret_key = _1password_secret_key
        if _1password_url is not None:
            self._1password_url = _1password_url
        if _1password_vaults is not None:
            self._1password_vaults = _1password_vaults
        if ad_auto_rotate is not None:
            self.ad_auto_rotate = ad_auto_rotate
        if ad_computer_base_dn is not None:
            self.ad_computer_base_dn = ad_computer_base_dn
        if ad_discover_local_users is not None:
            self.ad_discover_local_users = ad_discover_local_users
        if ad_domain_name is not None:
            self.ad_domain_name = ad_domain_name
        if ad_domain_users_path_template is not None:
            self.ad_domain_users_path_template = ad_domain_users_path_template
        if ad_local_users_ignore is not None:
            self.ad_local_users_ignore = ad_local_users_ignore
        if ad_local_users_path_template is not None:
            self.ad_local_users_path_template = ad_local_users_path_template
        if ad_rotation_hour is not None:
            self.ad_rotation_hour = ad_rotation_hour
        if ad_rotation_interval is not None:
            self.ad_rotation_interval = ad_rotation_interval
        if ad_sra_enable_rdp is not None:
            self.ad_sra_enable_rdp = ad_sra_enable_rdp
        if ad_target_name is not None:
            self.ad_target_name = ad_target_name
        if ad_targets_path_template is not None:
            self.ad_targets_path_template = ad_targets_path_template
        if ad_user_base_dn is not None:
            self.ad_user_base_dn = ad_user_base_dn
        if ad_user_groups is not None:
            self.ad_user_groups = ad_user_groups
        if as_ssh_port is not None:
            self.as_ssh_port = as_ssh_port
        if aws_key is not None:
            self.aws_key = aws_key
        if aws_key_id is not None:
            self.aws_key_id = aws_key_id
        if aws_region is not None:
            self.aws_region = aws_region
        if azure_client_id is not None:
            self.azure_client_id = azure_client_id
        if azure_kv_name is not None:
            self.azure_kv_name = azure_kv_name
        if azure_secret is not None:
            self.azure_secret = azure_secret
        if azure_tenant_id is not None:
            self.azure_tenant_id = azure_tenant_id
        if gcp_key is not None:
            self.gcp_key = gcp_key
        if hashi_json is not None:
            self.hashi_json = hashi_json
        if hashi_ns is not None:
            self.hashi_ns = hashi_ns
        if hashi_token is not None:
            self.hashi_token = hashi_token
        if hashi_url is not None:
            self.hashi_url = hashi_url
        if json is not None:
            self.json = json
        if k8s_ca_certificate is not None:
            self.k8s_ca_certificate = k8s_ca_certificate
        if k8s_client_certificate is not None:
            self.k8s_client_certificate = k8s_client_certificate
        if k8s_client_key is not None:
            self.k8s_client_key = k8s_client_key
        if k8s_namespace is not None:
            self.k8s_namespace = k8s_namespace
        if k8s_password is not None:
            self.k8s_password = k8s_password
        if k8s_skip_system is not None:
            self.k8s_skip_system = k8s_skip_system
        if k8s_token is not None:
            self.k8s_token = k8s_token
        if k8s_url is not None:
            self.k8s_url = k8s_url
        if k8s_username is not None:
            self.k8s_username = k8s_username
        self.name = name
        if protection_key is not None:
            self.protection_key = protection_key
        self.target_location = target_location
        if token is not None:
            self.token = token
        if type is not None:
            self.type = type
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def _1password_email(self):
        """Gets the _1password_email of this GatewayCreateMigration.  # noqa: E501

        1Password user email to connect to the API  # noqa: E501

        :return: The _1password_email of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self.__1password_email

    @_1password_email.setter
    def _1password_email(self, _1password_email):
        """Sets the _1password_email of this GatewayCreateMigration.

        1Password user email to connect to the API  # noqa: E501

        :param _1password_email: The _1password_email of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self.__1password_email = _1password_email

    @property
    def _1password_password(self):
        """Gets the _1password_password of this GatewayCreateMigration.  # noqa: E501

        1Password user password to connect to the API  # noqa: E501

        :return: The _1password_password of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self.__1password_password

    @_1password_password.setter
    def _1password_password(self, _1password_password):
        """Sets the _1password_password of this GatewayCreateMigration.

        1Password user password to connect to the API  # noqa: E501

        :param _1password_password: The _1password_password of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self.__1password_password = _1password_password

    @property
    def _1password_secret_key(self):
        """Gets the _1password_secret_key of this GatewayCreateMigration.  # noqa: E501

        1Password user secret key to connect to the API  # noqa: E501

        :return: The _1password_secret_key of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self.__1password_secret_key

    @_1password_secret_key.setter
    def _1password_secret_key(self, _1password_secret_key):
        """Sets the _1password_secret_key of this GatewayCreateMigration.

        1Password user secret key to connect to the API  # noqa: E501

        :param _1password_secret_key: The _1password_secret_key of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self.__1password_secret_key = _1password_secret_key

    @property
    def _1password_url(self):
        """Gets the _1password_url of this GatewayCreateMigration.  # noqa: E501

        1Password api container url  # noqa: E501

        :return: The _1password_url of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self.__1password_url

    @_1password_url.setter
    def _1password_url(self, _1password_url):
        """Sets the _1password_url of this GatewayCreateMigration.

        1Password api container url  # noqa: E501

        :param _1password_url: The _1password_url of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self.__1password_url = _1password_url

    @property
    def _1password_vaults(self):
        """Gets the _1password_vaults of this GatewayCreateMigration.  # noqa: E501

        1Password list of vault to get the items from  # noqa: E501

        :return: The _1password_vaults of this GatewayCreateMigration.  # noqa: E501
        :rtype: list[str]
        """
        return self.__1password_vaults

    @_1password_vaults.setter
    def _1password_vaults(self, _1password_vaults):
        """Sets the _1password_vaults of this GatewayCreateMigration.

        1Password list of vault to get the items from  # noqa: E501

        :param _1password_vaults: The _1password_vaults of this GatewayCreateMigration.  # noqa: E501
        :type: list[str]
        """

        self.__1password_vaults = _1password_vaults

    @property
    def ad_auto_rotate(self):
        """Gets the ad_auto_rotate of this GatewayCreateMigration.  # noqa: E501

        Enable/Disable automatic/recurrent rotation for migrated secrets. Default is false: only manual rotation is allowed for migrated secrets. If set to true, this command should be combined with --ad-rotation-interval and --ad-rotation-hour parameters (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_auto_rotate of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_auto_rotate

    @ad_auto_rotate.setter
    def ad_auto_rotate(self, ad_auto_rotate):
        """Sets the ad_auto_rotate of this GatewayCreateMigration.

        Enable/Disable automatic/recurrent rotation for migrated secrets. Default is false: only manual rotation is allowed for migrated secrets. If set to true, this command should be combined with --ad-rotation-interval and --ad-rotation-hour parameters (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_auto_rotate: The ad_auto_rotate of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_auto_rotate = ad_auto_rotate

    @property
    def ad_computer_base_dn(self):
        """Gets the ad_computer_base_dn of this GatewayCreateMigration.  # noqa: E501

        Distinguished Name of Computer objects (servers) to search in Active Directory e.g.: CN=Computers,DC=example,DC=com (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_computer_base_dn of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_computer_base_dn

    @ad_computer_base_dn.setter
    def ad_computer_base_dn(self, ad_computer_base_dn):
        """Sets the ad_computer_base_dn of this GatewayCreateMigration.

        Distinguished Name of Computer objects (servers) to search in Active Directory e.g.: CN=Computers,DC=example,DC=com (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_computer_base_dn: The ad_computer_base_dn of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_computer_base_dn = ad_computer_base_dn

    @property
    def ad_discover_local_users(self):
        """Gets the ad_discover_local_users of this GatewayCreateMigration.  # noqa: E501

        Enable/Disable discovery of local users from each domain server and migrate them as SSH Rotated Secrets. Default is false: only domain users will be migrated. Discovery of local users might require further installation of SSH on the servers, based on the supplied computer base DN. This will be implemented automatically as part of the migration process (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_discover_local_users of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_discover_local_users

    @ad_discover_local_users.setter
    def ad_discover_local_users(self, ad_discover_local_users):
        """Sets the ad_discover_local_users of this GatewayCreateMigration.

        Enable/Disable discovery of local users from each domain server and migrate them as SSH Rotated Secrets. Default is false: only domain users will be migrated. Discovery of local users might require further installation of SSH on the servers, based on the supplied computer base DN. This will be implemented automatically as part of the migration process (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_discover_local_users: The ad_discover_local_users of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_discover_local_users = ad_discover_local_users

    @property
    def ad_domain_name(self):
        """Gets the ad_domain_name of this GatewayCreateMigration.  # noqa: E501

        Active Directory Domain Name (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_domain_name of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_domain_name

    @ad_domain_name.setter
    def ad_domain_name(self, ad_domain_name):
        """Sets the ad_domain_name of this GatewayCreateMigration.

        Active Directory Domain Name (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_domain_name: The ad_domain_name of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_domain_name = ad_domain_name

    @property
    def ad_domain_users_path_template(self):
        """Gets the ad_domain_users_path_template of this GatewayCreateMigration.  # noqa: E501

        Path location template for migrating domain users as Rotated Secrets e.g.: .../DomainUsers/{{USERNAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_domain_users_path_template of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_domain_users_path_template

    @ad_domain_users_path_template.setter
    def ad_domain_users_path_template(self, ad_domain_users_path_template):
        """Sets the ad_domain_users_path_template of this GatewayCreateMigration.

        Path location template for migrating domain users as Rotated Secrets e.g.: .../DomainUsers/{{USERNAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_domain_users_path_template: The ad_domain_users_path_template of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_domain_users_path_template = ad_domain_users_path_template

    @property
    def ad_local_users_ignore(self):
        """Gets the ad_local_users_ignore of this GatewayCreateMigration.  # noqa: E501

        Comma-separated list of Local Users which should not be migrated (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_local_users_ignore of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_local_users_ignore

    @ad_local_users_ignore.setter
    def ad_local_users_ignore(self, ad_local_users_ignore):
        """Sets the ad_local_users_ignore of this GatewayCreateMigration.

        Comma-separated list of Local Users which should not be migrated (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_local_users_ignore: The ad_local_users_ignore of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_local_users_ignore = ad_local_users_ignore

    @property
    def ad_local_users_path_template(self):
        """Gets the ad_local_users_path_template of this GatewayCreateMigration.  # noqa: E501

        Path location template for migrating domain users as Rotated Secrets e.g.: .../LocalUsers/{{COMPUTER_NAME}}/{{USERNAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_local_users_path_template of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_local_users_path_template

    @ad_local_users_path_template.setter
    def ad_local_users_path_template(self, ad_local_users_path_template):
        """Sets the ad_local_users_path_template of this GatewayCreateMigration.

        Path location template for migrating domain users as Rotated Secrets e.g.: .../LocalUsers/{{COMPUTER_NAME}}/{{USERNAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_local_users_path_template: The ad_local_users_path_template of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_local_users_path_template = ad_local_users_path_template

    @property
    def ad_rotation_hour(self):
        """Gets the ad_rotation_hour of this GatewayCreateMigration.  # noqa: E501

        The hour of the scheduled rotation in UTC (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_rotation_hour of this GatewayCreateMigration.  # noqa: E501
        :rtype: int
        """
        return self._ad_rotation_hour

    @ad_rotation_hour.setter
    def ad_rotation_hour(self, ad_rotation_hour):
        """Sets the ad_rotation_hour of this GatewayCreateMigration.

        The hour of the scheduled rotation in UTC (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_rotation_hour: The ad_rotation_hour of this GatewayCreateMigration.  # noqa: E501
        :type: int
        """

        self._ad_rotation_hour = ad_rotation_hour

    @property
    def ad_rotation_interval(self):
        """Gets the ad_rotation_interval of this GatewayCreateMigration.  # noqa: E501

        The number of days to wait between every automatic rotation [1-365] (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_rotation_interval of this GatewayCreateMigration.  # noqa: E501
        :rtype: int
        """
        return self._ad_rotation_interval

    @ad_rotation_interval.setter
    def ad_rotation_interval(self, ad_rotation_interval):
        """Sets the ad_rotation_interval of this GatewayCreateMigration.

        The number of days to wait between every automatic rotation [1-365] (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_rotation_interval: The ad_rotation_interval of this GatewayCreateMigration.  # noqa: E501
        :type: int
        """

        self._ad_rotation_interval = ad_rotation_interval

    @property
    def ad_sra_enable_rdp(self):
        """Gets the ad_sra_enable_rdp of this GatewayCreateMigration.  # noqa: E501

        Enable/Disable RDP Secure Remote Access for the migrated local users rotated secrets. Default is false: rotated secrets will not be created with SRA (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_sra_enable_rdp of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_sra_enable_rdp

    @ad_sra_enable_rdp.setter
    def ad_sra_enable_rdp(self, ad_sra_enable_rdp):
        """Sets the ad_sra_enable_rdp of this GatewayCreateMigration.

        Enable/Disable RDP Secure Remote Access for the migrated local users rotated secrets. Default is false: rotated secrets will not be created with SRA (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_sra_enable_rdp: The ad_sra_enable_rdp of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_sra_enable_rdp = ad_sra_enable_rdp

    @property
    def ad_target_name(self):
        """Gets the ad_target_name of this GatewayCreateMigration.  # noqa: E501

        Active Directory LDAP Target Name. Server type should be Active Directory (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_target_name of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_target_name

    @ad_target_name.setter
    def ad_target_name(self, ad_target_name):
        """Sets the ad_target_name of this GatewayCreateMigration.

        Active Directory LDAP Target Name. Server type should be Active Directory (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_target_name: The ad_target_name of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_target_name = ad_target_name

    @property
    def ad_targets_path_template(self):
        """Gets the ad_targets_path_template of this GatewayCreateMigration.  # noqa: E501

        Path location template for migrating domain servers as SSH Targets e.g.: .../Servers/{{COMPUTER_NAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_targets_path_template of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_targets_path_template

    @ad_targets_path_template.setter
    def ad_targets_path_template(self, ad_targets_path_template):
        """Sets the ad_targets_path_template of this GatewayCreateMigration.

        Path location template for migrating domain servers as SSH Targets e.g.: .../Servers/{{COMPUTER_NAME}} (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_targets_path_template: The ad_targets_path_template of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_targets_path_template = ad_targets_path_template

    @property
    def ad_user_base_dn(self):
        """Gets the ad_user_base_dn of this GatewayCreateMigration.  # noqa: E501

        Distinguished Name of User objects to search in Active Directory, e.g.: CN=Users,DC=example,DC=com (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_user_base_dn of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_user_base_dn

    @ad_user_base_dn.setter
    def ad_user_base_dn(self, ad_user_base_dn):
        """Sets the ad_user_base_dn of this GatewayCreateMigration.

        Distinguished Name of User objects to search in Active Directory, e.g.: CN=Users,DC=example,DC=com (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_user_base_dn: The ad_user_base_dn of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_user_base_dn = ad_user_base_dn

    @property
    def ad_user_groups(self):
        """Gets the ad_user_groups of this GatewayCreateMigration.  # noqa: E501

        Comma-separated list of domain groups from which privileged domain users will be migrated (Relevant only for Active Directory migration)  # noqa: E501

        :return: The ad_user_groups of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._ad_user_groups

    @ad_user_groups.setter
    def ad_user_groups(self, ad_user_groups):
        """Sets the ad_user_groups of this GatewayCreateMigration.

        Comma-separated list of domain groups from which privileged domain users will be migrated (Relevant only for Active Directory migration)  # noqa: E501

        :param ad_user_groups: The ad_user_groups of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._ad_user_groups = ad_user_groups

    @property
    def as_ssh_port(self):
        """Gets the as_ssh_port of this GatewayCreateMigration.  # noqa: E501

        Set the SSH Port for further connection to the domain servers. Default is port 22 (Relevant only for Active Directory migration)  # noqa: E501

        :return: The as_ssh_port of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._as_ssh_port

    @as_ssh_port.setter
    def as_ssh_port(self, as_ssh_port):
        """Sets the as_ssh_port of this GatewayCreateMigration.

        Set the SSH Port for further connection to the domain servers. Default is port 22 (Relevant only for Active Directory migration)  # noqa: E501

        :param as_ssh_port: The as_ssh_port of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._as_ssh_port = as_ssh_port

    @property
    def aws_key(self):
        """Gets the aws_key of this GatewayCreateMigration.  # noqa: E501

        AWS Secret Access Key (relevant only for AWS migration)  # noqa: E501

        :return: The aws_key of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._aws_key

    @aws_key.setter
    def aws_key(self, aws_key):
        """Sets the aws_key of this GatewayCreateMigration.

        AWS Secret Access Key (relevant only for AWS migration)  # noqa: E501

        :param aws_key: The aws_key of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._aws_key = aws_key

    @property
    def aws_key_id(self):
        """Gets the aws_key_id of this GatewayCreateMigration.  # noqa: E501

        AWS Access Key ID with sufficient permissions to get all secrets, e.g. 'arn:aws:secretsmanager:[Region]:[AccountId]:secret:[/path/to/secrets/*]' (relevant only for AWS migration)  # noqa: E501

        :return: The aws_key_id of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._aws_key_id

    @aws_key_id.setter
    def aws_key_id(self, aws_key_id):
        """Sets the aws_key_id of this GatewayCreateMigration.

        AWS Access Key ID with sufficient permissions to get all secrets, e.g. 'arn:aws:secretsmanager:[Region]:[AccountId]:secret:[/path/to/secrets/*]' (relevant only for AWS migration)  # noqa: E501

        :param aws_key_id: The aws_key_id of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._aws_key_id = aws_key_id

    @property
    def aws_region(self):
        """Gets the aws_region of this GatewayCreateMigration.  # noqa: E501

        AWS region of the required Secrets Manager (relevant only for AWS migration)  # noqa: E501

        :return: The aws_region of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._aws_region

    @aws_region.setter
    def aws_region(self, aws_region):
        """Sets the aws_region of this GatewayCreateMigration.

        AWS region of the required Secrets Manager (relevant only for AWS migration)  # noqa: E501

        :param aws_region: The aws_region of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._aws_region = aws_region

    @property
    def azure_client_id(self):
        """Gets the azure_client_id of this GatewayCreateMigration.  # noqa: E501

        Azure Key Vault Access client ID, should be Azure AD App with a service principal (relevant only for Azure Key Vault migration)  # noqa: E501

        :return: The azure_client_id of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._azure_client_id

    @azure_client_id.setter
    def azure_client_id(self, azure_client_id):
        """Sets the azure_client_id of this GatewayCreateMigration.

        Azure Key Vault Access client ID, should be Azure AD App with a service principal (relevant only for Azure Key Vault migration)  # noqa: E501

        :param azure_client_id: The azure_client_id of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._azure_client_id = azure_client_id

    @property
    def azure_kv_name(self):
        """Gets the azure_kv_name of this GatewayCreateMigration.  # noqa: E501

        Azure Key Vault Name (relevant only for Azure Key Vault migration)  # noqa: E501

        :return: The azure_kv_name of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._azure_kv_name

    @azure_kv_name.setter
    def azure_kv_name(self, azure_kv_name):
        """Sets the azure_kv_name of this GatewayCreateMigration.

        Azure Key Vault Name (relevant only for Azure Key Vault migration)  # noqa: E501

        :param azure_kv_name: The azure_kv_name of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._azure_kv_name = azure_kv_name

    @property
    def azure_secret(self):
        """Gets the azure_secret of this GatewayCreateMigration.  # noqa: E501

        Azure Key Vault secret (relevant only for Azure Key Vault migration)  # noqa: E501

        :return: The azure_secret of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._azure_secret

    @azure_secret.setter
    def azure_secret(self, azure_secret):
        """Sets the azure_secret of this GatewayCreateMigration.

        Azure Key Vault secret (relevant only for Azure Key Vault migration)  # noqa: E501

        :param azure_secret: The azure_secret of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._azure_secret = azure_secret

    @property
    def azure_tenant_id(self):
        """Gets the azure_tenant_id of this GatewayCreateMigration.  # noqa: E501

        Azure Key Vault Access tenant ID (relevant only for Azure Key Vault migration)  # noqa: E501

        :return: The azure_tenant_id of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._azure_tenant_id

    @azure_tenant_id.setter
    def azure_tenant_id(self, azure_tenant_id):
        """Sets the azure_tenant_id of this GatewayCreateMigration.

        Azure Key Vault Access tenant ID (relevant only for Azure Key Vault migration)  # noqa: E501

        :param azure_tenant_id: The azure_tenant_id of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._azure_tenant_id = azure_tenant_id

    @property
    def gcp_key(self):
        """Gets the gcp_key of this GatewayCreateMigration.  # noqa: E501

        Base64-encoded GCP Service Account private key text with sufficient permissions to Secrets Manager, Minimum required permission is Secret Manager Secret Accessor, e.g. 'roles/secretmanager.secretAccessor' (relevant only for GCP migration)  # noqa: E501

        :return: The gcp_key of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._gcp_key

    @gcp_key.setter
    def gcp_key(self, gcp_key):
        """Sets the gcp_key of this GatewayCreateMigration.

        Base64-encoded GCP Service Account private key text with sufficient permissions to Secrets Manager, Minimum required permission is Secret Manager Secret Accessor, e.g. 'roles/secretmanager.secretAccessor' (relevant only for GCP migration)  # noqa: E501

        :param gcp_key: The gcp_key of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._gcp_key = gcp_key

    @property
    def hashi_json(self):
        """Gets the hashi_json of this GatewayCreateMigration.  # noqa: E501

        Import secret key as json value or independent secrets (relevant only for HasiCorp Vault migration)  # noqa: E501

        :return: The hashi_json of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._hashi_json

    @hashi_json.setter
    def hashi_json(self, hashi_json):
        """Sets the hashi_json of this GatewayCreateMigration.

        Import secret key as json value or independent secrets (relevant only for HasiCorp Vault migration)  # noqa: E501

        :param hashi_json: The hashi_json of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._hashi_json = hashi_json

    @property
    def hashi_ns(self):
        """Gets the hashi_ns of this GatewayCreateMigration.  # noqa: E501

        HashiCorp Vault Namespaces is a comma-separated list of namespaces which need to be imported into Akeyless Vault. For every provided namespace, all its child namespaces are imported as well, e.g. nmsp/subnmsp1/subnmsp2,nmsp/anothernmsp. By default, import all namespaces (relevant only for HasiCorp Vault migration)  # noqa: E501

        :return: The hashi_ns of this GatewayCreateMigration.  # noqa: E501
        :rtype: list[str]
        """
        return self._hashi_ns

    @hashi_ns.setter
    def hashi_ns(self, hashi_ns):
        """Sets the hashi_ns of this GatewayCreateMigration.

        HashiCorp Vault Namespaces is a comma-separated list of namespaces which need to be imported into Akeyless Vault. For every provided namespace, all its child namespaces are imported as well, e.g. nmsp/subnmsp1/subnmsp2,nmsp/anothernmsp. By default, import all namespaces (relevant only for HasiCorp Vault migration)  # noqa: E501

        :param hashi_ns: The hashi_ns of this GatewayCreateMigration.  # noqa: E501
        :type: list[str]
        """

        self._hashi_ns = hashi_ns

    @property
    def hashi_token(self):
        """Gets the hashi_token of this GatewayCreateMigration.  # noqa: E501

        HashiCorp Vault access token with sufficient permissions to preform list & read operations on secrets objects (relevant only for HasiCorp Vault migration)  # noqa: E501

        :return: The hashi_token of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._hashi_token

    @hashi_token.setter
    def hashi_token(self, hashi_token):
        """Sets the hashi_token of this GatewayCreateMigration.

        HashiCorp Vault access token with sufficient permissions to preform list & read operations on secrets objects (relevant only for HasiCorp Vault migration)  # noqa: E501

        :param hashi_token: The hashi_token of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._hashi_token = hashi_token

    @property
    def hashi_url(self):
        """Gets the hashi_url of this GatewayCreateMigration.  # noqa: E501

        HashiCorp Vault API URL, e.g. https://vault-mgr01:8200 (relevant only for HasiCorp Vault migration)  # noqa: E501

        :return: The hashi_url of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._hashi_url

    @hashi_url.setter
    def hashi_url(self, hashi_url):
        """Sets the hashi_url of this GatewayCreateMigration.

        HashiCorp Vault API URL, e.g. https://vault-mgr01:8200 (relevant only for HasiCorp Vault migration)  # noqa: E501

        :param hashi_url: The hashi_url of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._hashi_url = hashi_url

    @property
    def json(self):
        """Gets the json of this GatewayCreateMigration.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayCreateMigration.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayCreateMigration.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayCreateMigration.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def k8s_ca_certificate(self):
        """Gets the k8s_ca_certificate of this GatewayCreateMigration.  # noqa: E501

        For Certificate Authentication method K8s Cluster CA certificate (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :return: The k8s_ca_certificate of this GatewayCreateMigration.  # noqa: E501
        :rtype: list[int]
        """
        return self._k8s_ca_certificate

    @k8s_ca_certificate.setter
    def k8s_ca_certificate(self, k8s_ca_certificate):
        """Sets the k8s_ca_certificate of this GatewayCreateMigration.

        For Certificate Authentication method K8s Cluster CA certificate (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :param k8s_ca_certificate: The k8s_ca_certificate of this GatewayCreateMigration.  # noqa: E501
        :type: list[int]
        """

        self._k8s_ca_certificate = k8s_ca_certificate

    @property
    def k8s_client_certificate(self):
        """Gets the k8s_client_certificate of this GatewayCreateMigration.  # noqa: E501

        K8s Client certificate with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :return: The k8s_client_certificate of this GatewayCreateMigration.  # noqa: E501
        :rtype: list[int]
        """
        return self._k8s_client_certificate

    @k8s_client_certificate.setter
    def k8s_client_certificate(self, k8s_client_certificate):
        """Sets the k8s_client_certificate of this GatewayCreateMigration.

        K8s Client certificate with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :param k8s_client_certificate: The k8s_client_certificate of this GatewayCreateMigration.  # noqa: E501
        :type: list[int]
        """

        self._k8s_client_certificate = k8s_client_certificate

    @property
    def k8s_client_key(self):
        """Gets the k8s_client_key of this GatewayCreateMigration.  # noqa: E501

        K8s Client key (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :return: The k8s_client_key of this GatewayCreateMigration.  # noqa: E501
        :rtype: list[int]
        """
        return self._k8s_client_key

    @k8s_client_key.setter
    def k8s_client_key(self, k8s_client_key):
        """Sets the k8s_client_key of this GatewayCreateMigration.

        K8s Client key (relevant only for K8s migration with Certificate Authentication method)  # noqa: E501

        :param k8s_client_key: The k8s_client_key of this GatewayCreateMigration.  # noqa: E501
        :type: list[int]
        """

        self._k8s_client_key = k8s_client_key

    @property
    def k8s_namespace(self):
        """Gets the k8s_namespace of this GatewayCreateMigration.  # noqa: E501

        K8s Namespace, Use this field to import secrets from a particular namespace only. By default, the secrets are imported from all namespaces (relevant only for K8s migration)  # noqa: E501

        :return: The k8s_namespace of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._k8s_namespace

    @k8s_namespace.setter
    def k8s_namespace(self, k8s_namespace):
        """Sets the k8s_namespace of this GatewayCreateMigration.

        K8s Namespace, Use this field to import secrets from a particular namespace only. By default, the secrets are imported from all namespaces (relevant only for K8s migration)  # noqa: E501

        :param k8s_namespace: The k8s_namespace of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._k8s_namespace = k8s_namespace

    @property
    def k8s_password(self):
        """Gets the k8s_password of this GatewayCreateMigration.  # noqa: E501

        K8s Client password (relevant only for K8s migration with Password Authentication method)  # noqa: E501

        :return: The k8s_password of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._k8s_password

    @k8s_password.setter
    def k8s_password(self, k8s_password):
        """Sets the k8s_password of this GatewayCreateMigration.

        K8s Client password (relevant only for K8s migration with Password Authentication method)  # noqa: E501

        :param k8s_password: The k8s_password of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._k8s_password = k8s_password

    @property
    def k8s_skip_system(self):
        """Gets the k8s_skip_system of this GatewayCreateMigration.  # noqa: E501

        K8s Skip Control Plane Secrets, This option allows to avoid importing secrets from system namespaces (relevant only for K8s migration)  # noqa: E501

        :return: The k8s_skip_system of this GatewayCreateMigration.  # noqa: E501
        :rtype: bool
        """
        return self._k8s_skip_system

    @k8s_skip_system.setter
    def k8s_skip_system(self, k8s_skip_system):
        """Sets the k8s_skip_system of this GatewayCreateMigration.

        K8s Skip Control Plane Secrets, This option allows to avoid importing secrets from system namespaces (relevant only for K8s migration)  # noqa: E501

        :param k8s_skip_system: The k8s_skip_system of this GatewayCreateMigration.  # noqa: E501
        :type: bool
        """

        self._k8s_skip_system = k8s_skip_system

    @property
    def k8s_token(self):
        """Gets the k8s_token of this GatewayCreateMigration.  # noqa: E501

        For Token Authentication method K8s Bearer Token with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Token Authentication method)  # noqa: E501

        :return: The k8s_token of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._k8s_token

    @k8s_token.setter
    def k8s_token(self, k8s_token):
        """Sets the k8s_token of this GatewayCreateMigration.

        For Token Authentication method K8s Bearer Token with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Token Authentication method)  # noqa: E501

        :param k8s_token: The k8s_token of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._k8s_token = k8s_token

    @property
    def k8s_url(self):
        """Gets the k8s_url of this GatewayCreateMigration.  # noqa: E501

        K8s API Server URL, e.g. https://k8s-api.mycompany.com:6443 (relevant only for K8s migration)  # noqa: E501

        :return: The k8s_url of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._k8s_url

    @k8s_url.setter
    def k8s_url(self, k8s_url):
        """Sets the k8s_url of this GatewayCreateMigration.

        K8s API Server URL, e.g. https://k8s-api.mycompany.com:6443 (relevant only for K8s migration)  # noqa: E501

        :param k8s_url: The k8s_url of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._k8s_url = k8s_url

    @property
    def k8s_username(self):
        """Gets the k8s_username of this GatewayCreateMigration.  # noqa: E501

        For Password Authentication method K8s Client username with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Password Authentication method)  # noqa: E501

        :return: The k8s_username of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._k8s_username

    @k8s_username.setter
    def k8s_username(self, k8s_username):
        """Sets the k8s_username of this GatewayCreateMigration.

        For Password Authentication method K8s Client username with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Password Authentication method)  # noqa: E501

        :param k8s_username: The k8s_username of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._k8s_username = k8s_username

    @property
    def name(self):
        """Gets the name of this GatewayCreateMigration.  # noqa: E501

        Migration name  # noqa: E501

        :return: The name of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayCreateMigration.

        Migration name  # noqa: E501

        :param name: The name of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def protection_key(self):
        """Gets the protection_key of this GatewayCreateMigration.  # noqa: E501

        The name of the key that protects the classic key value (if empty, the account default key will be used)  # noqa: E501

        :return: The protection_key of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this GatewayCreateMigration.

        The name of the key that protects the classic key value (if empty, the account default key will be used)  # noqa: E501

        :param protection_key: The protection_key of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def target_location(self):
        """Gets the target_location of this GatewayCreateMigration.  # noqa: E501

        Target location in Akeyless for imported secrets  # noqa: E501

        :return: The target_location of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._target_location

    @target_location.setter
    def target_location(self, target_location):
        """Sets the target_location of this GatewayCreateMigration.

        Target location in Akeyless for imported secrets  # noqa: E501

        :param target_location: The target_location of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_location is None:  # noqa: E501
            raise ValueError("Invalid value for `target_location`, must not be `None`")  # noqa: E501

        self._target_location = target_location

    @property
    def token(self):
        """Gets the token of this GatewayCreateMigration.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayCreateMigration.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def type(self):
        """Gets the type of this GatewayCreateMigration.  # noqa: E501

        Migration type (hashi/aws/gcp/k8s/azure_kv/1password/active_directory)  # noqa: E501

        :return: The type of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GatewayCreateMigration.

        Migration type (hashi/aws/gcp/k8s/azure_kv/1password/active_directory)  # noqa: E501

        :param type: The type of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayCreateMigration.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayCreateMigration.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayCreateMigration.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayCreateMigration.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayCreateMigration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayCreateMigration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class OAuth2AccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'audience': 'str',
        'bound_claims': 'list[OAuth2CustomClaim]',
        'bound_clients_id': 'list[str]',
        'issuer': 'str',
        'jwks_uri': 'str',
        'unique_identifier': 'str'
    }

    attribute_map = {
        'audience': 'audience',
        'bound_claims': 'bound_claims',
        'bound_clients_id': 'bound_clients_id',
        'issuer': 'issuer',
        'jwks_uri': 'jwks_uri',
        'unique_identifier': 'unique_identifier'
    }

    def __init__(self, audience=None, bound_claims=None, bound_clients_id=None, issuer=None, jwks_uri=None, unique_identifier=None, local_vars_configuration=None):  # noqa: E501
        """OAuth2AccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._audience = None
        self._bound_claims = None
        self._bound_clients_id = None
        self._issuer = None
        self._jwks_uri = None
        self._unique_identifier = None
        self.discriminator = None

        if audience is not None:
            self.audience = audience
        if bound_claims is not None:
            self.bound_claims = bound_claims
        if bound_clients_id is not None:
            self.bound_clients_id = bound_clients_id
        if issuer is not None:
            self.issuer = issuer
        if jwks_uri is not None:
            self.jwks_uri = jwks_uri
        if unique_identifier is not None:
            self.unique_identifier = unique_identifier

    @property
    def audience(self):
        """Gets the audience of this OAuth2AccessRules.  # noqa: E501

        The audience in the JWT.  # noqa: E501

        :return: The audience of this OAuth2AccessRules.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this OAuth2AccessRules.

        The audience in the JWT.  # noqa: E501

        :param audience: The audience of this OAuth2AccessRules.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def bound_claims(self):
        """Gets the bound_claims of this OAuth2AccessRules.  # noqa: E501

        The claims that login is restricted to.  # noqa: E501

        :return: The bound_claims of this OAuth2AccessRules.  # noqa: E501
        :rtype: list[OAuth2CustomClaim]
        """
        return self._bound_claims

    @bound_claims.setter
    def bound_claims(self, bound_claims):
        """Sets the bound_claims of this OAuth2AccessRules.

        The claims that login is restricted to.  # noqa: E501

        :param bound_claims: The bound_claims of this OAuth2AccessRules.  # noqa: E501
        :type: list[OAuth2CustomClaim]
        """

        self._bound_claims = bound_claims

    @property
    def bound_clients_id(self):
        """Gets the bound_clients_id of this OAuth2AccessRules.  # noqa: E501

        The clients ids that login is restricted to.  # noqa: E501

        :return: The bound_clients_id of this OAuth2AccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_clients_id

    @bound_clients_id.setter
    def bound_clients_id(self, bound_clients_id):
        """Sets the bound_clients_id of this OAuth2AccessRules.

        The clients ids that login is restricted to.  # noqa: E501

        :param bound_clients_id: The bound_clients_id of this OAuth2AccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_clients_id = bound_clients_id

    @property
    def issuer(self):
        """Gets the issuer of this OAuth2AccessRules.  # noqa: E501

        Issuer URL  # noqa: E501

        :return: The issuer of this OAuth2AccessRules.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this OAuth2AccessRules.

        Issuer URL  # noqa: E501

        :param issuer: The issuer of this OAuth2AccessRules.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def jwks_uri(self):
        """Gets the jwks_uri of this OAuth2AccessRules.  # noqa: E501

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :return: The jwks_uri of this OAuth2AccessRules.  # noqa: E501
        :rtype: str
        """
        return self._jwks_uri

    @jwks_uri.setter
    def jwks_uri(self, jwks_uri):
        """Sets the jwks_uri of this OAuth2AccessRules.

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :param jwks_uri: The jwks_uri of this OAuth2AccessRules.  # noqa: E501
        :type: str
        """

        self._jwks_uri = jwks_uri

    @property
    def unique_identifier(self):
        """Gets the unique_identifier of this OAuth2AccessRules.  # noqa: E501

        A unique identifier to distinguish different users  # noqa: E501

        :return: The unique_identifier of this OAuth2AccessRules.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier

    @unique_identifier.setter
    def unique_identifier(self, unique_identifier):
        """Sets the unique_identifier of this OAuth2AccessRules.

        A unique identifier to distinguish different users  # noqa: E501

        :param unique_identifier: The unique_identifier of this OAuth2AccessRules.  # noqa: E501
        :type: str
        """

        self._unique_identifier = unique_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2AccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OAuth2AccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class OIDCAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_redirect_ur_is': 'list[str]',
        'audience': 'str',
        'bound_claims': 'list[OIDCCustomClaim]',
        'client_id': 'str',
        'client_secret': 'str',
        'is_internal': 'bool',
        'issuer': 'str',
        'required_scopes': 'list[str]',
        'required_scopes_prefix': 'str',
        'unique_identifier': 'str'
    }

    attribute_map = {
        'allowed_redirect_ur_is': 'allowed_redirect_URIs',
        'audience': 'audience',
        'bound_claims': 'bound_claims',
        'client_id': 'client_id',
        'client_secret': 'client_secret',
        'is_internal': 'is_internal',
        'issuer': 'issuer',
        'required_scopes': 'required_scopes',
        'required_scopes_prefix': 'required_scopes_prefix',
        'unique_identifier': 'unique_identifier'
    }

    def __init__(self, allowed_redirect_ur_is=None, audience=None, bound_claims=None, client_id=None, client_secret=None, is_internal=None, issuer=None, required_scopes=None, required_scopes_prefix=None, unique_identifier=None, local_vars_configuration=None):  # noqa: E501
        """OIDCAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_redirect_ur_is = None
        self._audience = None
        self._bound_claims = None
        self._client_id = None
        self._client_secret = None
        self._is_internal = None
        self._issuer = None
        self._required_scopes = None
        self._required_scopes_prefix = None
        self._unique_identifier = None
        self.discriminator = None

        if allowed_redirect_ur_is is not None:
            self.allowed_redirect_ur_is = allowed_redirect_ur_is
        if audience is not None:
            self.audience = audience
        if bound_claims is not None:
            self.bound_claims = bound_claims
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if is_internal is not None:
            self.is_internal = is_internal
        if issuer is not None:
            self.issuer = issuer
        if required_scopes is not None:
            self.required_scopes = required_scopes
        if required_scopes_prefix is not None:
            self.required_scopes_prefix = required_scopes_prefix
        if unique_identifier is not None:
            self.unique_identifier = unique_identifier

    @property
    def allowed_redirect_ur_is(self):
        """Gets the allowed_redirect_ur_is of this OIDCAccessRules.  # noqa: E501

        Allowed redirect URIs after the authentication  # noqa: E501

        :return: The allowed_redirect_ur_is of this OIDCAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_redirect_ur_is

    @allowed_redirect_ur_is.setter
    def allowed_redirect_ur_is(self, allowed_redirect_ur_is):
        """Sets the allowed_redirect_ur_is of this OIDCAccessRules.

        Allowed redirect URIs after the authentication  # noqa: E501

        :param allowed_redirect_ur_is: The allowed_redirect_ur_is of this OIDCAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._allowed_redirect_ur_is = allowed_redirect_ur_is

    @property
    def audience(self):
        """Gets the audience of this OIDCAccessRules.  # noqa: E501

        Audience claim to be used as part of the authentication flow. In case set, it must match the one configured on the Identity Provider's Application  # noqa: E501

        :return: The audience of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this OIDCAccessRules.

        Audience claim to be used as part of the authentication flow. In case set, it must match the one configured on the Identity Provider's Application  # noqa: E501

        :param audience: The audience of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def bound_claims(self):
        """Gets the bound_claims of this OIDCAccessRules.  # noqa: E501

        The claims that login is restricted to.  # noqa: E501

        :return: The bound_claims of this OIDCAccessRules.  # noqa: E501
        :rtype: list[OIDCCustomClaim]
        """
        return self._bound_claims

    @bound_claims.setter
    def bound_claims(self, bound_claims):
        """Sets the bound_claims of this OIDCAccessRules.

        The claims that login is restricted to.  # noqa: E501

        :param bound_claims: The bound_claims of this OIDCAccessRules.  # noqa: E501
        :type: list[OIDCCustomClaim]
        """

        self._bound_claims = bound_claims

    @property
    def client_id(self):
        """Gets the client_id of this OIDCAccessRules.  # noqa: E501

        Client ID  # noqa: E501

        :return: The client_id of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this OIDCAccessRules.

        Client ID  # noqa: E501

        :param client_id: The client_id of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this OIDCAccessRules.  # noqa: E501

        Client Secret  # noqa: E501

        :return: The client_secret of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this OIDCAccessRules.

        Client Secret  # noqa: E501

        :param client_secret: The client_secret of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def is_internal(self):
        """Gets the is_internal of this OIDCAccessRules.  # noqa: E501

        IsInternal indicates whether this is an internal Auth Method where the client has no control over it, or it was created by the client e.g - Sign In with Google will create an OIDC Auth Method with IsInternal=true  # noqa: E501

        :return: The is_internal of this OIDCAccessRules.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal):
        """Sets the is_internal of this OIDCAccessRules.

        IsInternal indicates whether this is an internal Auth Method where the client has no control over it, or it was created by the client e.g - Sign In with Google will create an OIDC Auth Method with IsInternal=true  # noqa: E501

        :param is_internal: The is_internal of this OIDCAccessRules.  # noqa: E501
        :type: bool
        """

        self._is_internal = is_internal

    @property
    def issuer(self):
        """Gets the issuer of this OIDCAccessRules.  # noqa: E501

        Issuer URL  # noqa: E501

        :return: The issuer of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this OIDCAccessRules.

        Issuer URL  # noqa: E501

        :param issuer: The issuer of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def required_scopes(self):
        """Gets the required_scopes of this OIDCAccessRules.  # noqa: E501

        A list of required scopes to request from the oidc provider, and to check on the token  # noqa: E501

        :return: The required_scopes of this OIDCAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._required_scopes

    @required_scopes.setter
    def required_scopes(self, required_scopes):
        """Sets the required_scopes of this OIDCAccessRules.

        A list of required scopes to request from the oidc provider, and to check on the token  # noqa: E501

        :param required_scopes: The required_scopes of this OIDCAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._required_scopes = required_scopes

    @property
    def required_scopes_prefix(self):
        """Gets the required_scopes_prefix of this OIDCAccessRules.  # noqa: E501

        A prefix to add to the required scopes (for example, azures' Application ID URI)  # noqa: E501

        :return: The required_scopes_prefix of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._required_scopes_prefix

    @required_scopes_prefix.setter
    def required_scopes_prefix(self, required_scopes_prefix):
        """Sets the required_scopes_prefix of this OIDCAccessRules.

        A prefix to add to the required scopes (for example, azures' Application ID URI)  # noqa: E501

        :param required_scopes_prefix: The required_scopes_prefix of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._required_scopes_prefix = required_scopes_prefix

    @property
    def unique_identifier(self):
        """Gets the unique_identifier of this OIDCAccessRules.  # noqa: E501

        A unique identifier to distinguish different users  # noqa: E501

        :return: The unique_identifier of this OIDCAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier

    @unique_identifier.setter
    def unique_identifier(self, unique_identifier):
        """Sets the unique_identifier of this OIDCAccessRules.

        A unique identifier to distinguish different users  # noqa: E501

        :param unique_identifier: The unique_identifier of this OIDCAccessRules.  # noqa: E501
        :type: str
        """

        self._unique_identifier = unique_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OIDCAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OIDCAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class DynamicSecretProducerInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'failure_message': 'str',
        'gw_cluster_id': 'int',
        'producer_last_keep_alive': 'str',
        'producer_metadata': 'str',
        'producer_status': 'str',
        'producer_type': 'str'
    }

    attribute_map = {
        'failure_message': 'failure_message',
        'gw_cluster_id': 'gw_cluster_id',
        'producer_last_keep_alive': 'producer_last_keep_alive',
        'producer_metadata': 'producer_metadata',
        'producer_status': 'producer_status',
        'producer_type': 'producer_type'
    }

    def __init__(self, failure_message=None, gw_cluster_id=None, producer_last_keep_alive=None, producer_metadata=None, producer_status=None, producer_type=None, local_vars_configuration=None):  # noqa: E501
        """DynamicSecretProducerInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._failure_message = None
        self._gw_cluster_id = None
        self._producer_last_keep_alive = None
        self._producer_metadata = None
        self._producer_status = None
        self._producer_type = None
        self.discriminator = None

        if failure_message is not None:
            self.failure_message = failure_message
        if gw_cluster_id is not None:
            self.gw_cluster_id = gw_cluster_id
        if producer_last_keep_alive is not None:
            self.producer_last_keep_alive = producer_last_keep_alive
        if producer_metadata is not None:
            self.producer_metadata = producer_metadata
        if producer_status is not None:
            self.producer_status = producer_status
        if producer_type is not None:
            self.producer_type = producer_type

    @property
    def failure_message(self):
        """Gets the failure_message of this DynamicSecretProducerInfo.  # noqa: E501


        :return: The failure_message of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """Sets the failure_message of this DynamicSecretProducerInfo.


        :param failure_message: The failure_message of this DynamicSecretProducerInfo.  # noqa: E501
        :type: str
        """

        self._failure_message = failure_message

    @property
    def gw_cluster_id(self):
        """Gets the gw_cluster_id of this DynamicSecretProducerInfo.  # noqa: E501


        :return: The gw_cluster_id of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: int
        """
        return self._gw_cluster_id

    @gw_cluster_id.setter
    def gw_cluster_id(self, gw_cluster_id):
        """Sets the gw_cluster_id of this DynamicSecretProducerInfo.


        :param gw_cluster_id: The gw_cluster_id of this DynamicSecretProducerInfo.  # noqa: E501
        :type: int
        """

        self._gw_cluster_id = gw_cluster_id

    @property
    def producer_last_keep_alive(self):
        """Gets the producer_last_keep_alive of this DynamicSecretProducerInfo.  # noqa: E501


        :return: The producer_last_keep_alive of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: str
        """
        return self._producer_last_keep_alive

    @producer_last_keep_alive.setter
    def producer_last_keep_alive(self, producer_last_keep_alive):
        """Sets the producer_last_keep_alive of this DynamicSecretProducerInfo.


        :param producer_last_keep_alive: The producer_last_keep_alive of this DynamicSecretProducerInfo.  # noqa: E501
        :type: str
        """

        self._producer_last_keep_alive = producer_last_keep_alive

    @property
    def producer_metadata(self):
        """Gets the producer_metadata of this DynamicSecretProducerInfo.  # noqa: E501


        :return: The producer_metadata of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: str
        """
        return self._producer_metadata

    @producer_metadata.setter
    def producer_metadata(self, producer_metadata):
        """Sets the producer_metadata of this DynamicSecretProducerInfo.


        :param producer_metadata: The producer_metadata of this DynamicSecretProducerInfo.  # noqa: E501
        :type: str
        """

        self._producer_metadata = producer_metadata

    @property
    def producer_status(self):
        """Gets the producer_status of this DynamicSecretProducerInfo.  # noqa: E501

        RotationStatus defines types of rotation Status  # noqa: E501

        :return: The producer_status of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: str
        """
        return self._producer_status

    @producer_status.setter
    def producer_status(self, producer_status):
        """Sets the producer_status of this DynamicSecretProducerInfo.

        RotationStatus defines types of rotation Status  # noqa: E501

        :param producer_status: The producer_status of this DynamicSecretProducerInfo.  # noqa: E501
        :type: str
        """

        self._producer_status = producer_status

    @property
    def producer_type(self):
        """Gets the producer_type of this DynamicSecretProducerInfo.  # noqa: E501


        :return: The producer_type of this DynamicSecretProducerInfo.  # noqa: E501
        :rtype: str
        """
        return self._producer_type

    @producer_type.setter
    def producer_type(self, producer_type):
        """Sets the producer_type of this DynamicSecretProducerInfo.


        :param producer_type: The producer_type of this DynamicSecretProducerInfo.  # noqa: E501
        :type: str
        """

        self._producer_type = producer_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DynamicSecretProducerInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DynamicSecretProducerInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AuthMethodRoleAssociation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_ops': 'list[str]',
        'assoc_id': 'str',
        'auth_method_sub_claims': 'dict(str, list[str])',
        'role_name': 'str',
        'rules': 'Rules'
    }

    attribute_map = {
        'allowed_ops': 'allowed_ops',
        'assoc_id': 'assoc_id',
        'auth_method_sub_claims': 'auth_method_sub_claims',
        'role_name': 'role_name',
        'rules': 'rules'
    }

    def __init__(self, allowed_ops=None, assoc_id=None, auth_method_sub_claims=None, role_name=None, rules=None, local_vars_configuration=None):  # noqa: E501
        """AuthMethodRoleAssociation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_ops = None
        self._assoc_id = None
        self._auth_method_sub_claims = None
        self._role_name = None
        self._rules = None
        self.discriminator = None

        if allowed_ops is not None:
            self.allowed_ops = allowed_ops
        if assoc_id is not None:
            self.assoc_id = assoc_id
        if auth_method_sub_claims is not None:
            self.auth_method_sub_claims = auth_method_sub_claims
        if role_name is not None:
            self.role_name = role_name
        if rules is not None:
            self.rules = rules

    @property
    def allowed_ops(self):
        """Gets the allowed_ops of this AuthMethodRoleAssociation.  # noqa: E501


        :return: The allowed_ops of this AuthMethodRoleAssociation.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_ops

    @allowed_ops.setter
    def allowed_ops(self, allowed_ops):
        """Sets the allowed_ops of this AuthMethodRoleAssociation.


        :param allowed_ops: The allowed_ops of this AuthMethodRoleAssociation.  # noqa: E501
        :type: list[str]
        """

        self._allowed_ops = allowed_ops

    @property
    def assoc_id(self):
        """Gets the assoc_id of this AuthMethodRoleAssociation.  # noqa: E501


        :return: The assoc_id of this AuthMethodRoleAssociation.  # noqa: E501
        :rtype: str
        """
        return self._assoc_id

    @assoc_id.setter
    def assoc_id(self, assoc_id):
        """Sets the assoc_id of this AuthMethodRoleAssociation.


        :param assoc_id: The assoc_id of this AuthMethodRoleAssociation.  # noqa: E501
        :type: str
        """

        self._assoc_id = assoc_id

    @property
    def auth_method_sub_claims(self):
        """Gets the auth_method_sub_claims of this AuthMethodRoleAssociation.  # noqa: E501


        :return: The auth_method_sub_claims of this AuthMethodRoleAssociation.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._auth_method_sub_claims

    @auth_method_sub_claims.setter
    def auth_method_sub_claims(self, auth_method_sub_claims):
        """Sets the auth_method_sub_claims of this AuthMethodRoleAssociation.


        :param auth_method_sub_claims: The auth_method_sub_claims of this AuthMethodRoleAssociation.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._auth_method_sub_claims = auth_method_sub_claims

    @property
    def role_name(self):
        """Gets the role_name of this AuthMethodRoleAssociation.  # noqa: E501


        :return: The role_name of this AuthMethodRoleAssociation.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this AuthMethodRoleAssociation.


        :param role_name: The role_name of this AuthMethodRoleAssociation.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def rules(self):
        """Gets the rules of this AuthMethodRoleAssociation.  # noqa: E501


        :return: The rules of this AuthMethodRoleAssociation.  # noqa: E501
        :rtype: Rules
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this AuthMethodRoleAssociation.


        :param rules: The rules of this AuthMethodRoleAssociation.  # noqa: E501
        :type: Rules
        """

        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthMethodRoleAssociation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthMethodRoleAssociation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.list_auth_methods_output import ListAuthMethodsOutput  # noqa: E501
from akeyless.rest import ApiException

class TestListAuthMethodsOutput(unittest.TestCase):
    """ListAuthMethodsOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListAuthMethodsOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.list_auth_methods_output.ListAuthMethodsOutput()  # noqa: E501
        if include_optional :
            return ListAuthMethodsOutput(
                auth_methods = [
                    akeyless.models.auth_method_represents_a_single_auth_method/.AuthMethod represents a single Auth method.(
                        access_info = akeyless.models.auth_method_access_info_includes_auth_method_access_information/.AuthMethodAccessInfo includes auth method access information.(
                            access_expires = 56, 
                            api_key_access_rules = akeyless.models.api_key_access_rules_is_a_set_of_rules_for_api_key_access_type/.APIKeyAccessRules is a set of rules for API Key access type.(
                                alg = '0', 
                                key = '0', ), 
                            aws_iam_access_rules = akeyless.models.awsiam_access_rules_contains_access_rules_specific_to_aws_iam/.AWSIAMAccessRules contains access rules specific to AWS IAM.(
                                account_id = [
                                    '0'
                                    ], 
                                arn = [
                                    '0'
                                    ], 
                                resource_id = [
                                    '0'
                                    ], 
                                role_id = [
                                    '0'
                                    ], 
                                role_name = [
                                    '0'
                                    ], 
                                sts_endpoint = '0', 
                                user_id = [
                                    '0'
                                    ], 
                                user_name = [
                                    '0'
                                    ], ), 
                            azure_ad_access_rules = akeyless.models.azure_ad_access_rules.AzureADAccessRules(
                                ad_endpoint = '0', 
                                bound_group_ids = [
                                    '0'
                                    ], 
                                bound_resource_groups = [
                                    '0'
                                    ], 
                                bound_resource_ids = [
                                    '0'
                                    ], 
                                bound_resource_names = [
                                    '0'
                                    ], 
                                bound_resource_providers = [
                                    '0'
                                    ], 
                                bound_resource_types = [
                                    '0'
                                    ], 
                                bound_service_principal_ids = [
                                    '0'
                                    ], 
                                bound_subscription_ids = [
                                    '0'
                                    ], 
                                bound_tenant_id = '0', 
                                issuer = '0', 
                                jwks_uri = '0', ), 
                            cidr_whitelist = '0', 
                            email_pass_access_rules = akeyless.models.email_pass_access_rules_is_a_set_of_rules_for_email_password_access_type/.EmailPassAccessRules is a set of rules for email password access type.(
                                alg = '0', 
                                email = '0', 
                                hash_pass = '0', ), 
                            huawei_access_rules = akeyless.models.huawei_access_rules_defines_access_rules_specific_to_huawei_authentication/.HuaweiAccessRules defines access rules specific to Huawei authentication.(
                                auth_endpoint = '0', 
                                domain_id = [
                                    '0'
                                    ], 
                                domain_name = [
                                    '0'
                                    ], 
                                tenant_id = [
                                    '0'
                                    ], 
                                tenant_name = [
                                    '0'
                                    ], ), 
                            ldap_access_rules = akeyless.models.ldap_access_rules_includes_access_rules_specific_to_ldap_authentication/.LDAPAccessRules includes access rules specific to LDAP authentication.(
                                alg = '0', 
                                key = '0', ), 
                            oauth2_access_rules = akeyless.models.o_auth2_access_rules.OAuth2AccessRules(
                                audience = '0', 
                                bound_claims = [
                                    akeyless.models.o_auth2_custom_claim.OAuth2CustomClaim(
                                        name = '0', 
                                        values = [
                                            '0'
                                            ], )
                                    ], 
                                bound_clients_id = [
                                    '0'
                                    ], 
                                issuer = '0', 
                                jwks_uri = '0', ), 
                            rules_type = '0', 
                            saml_access_rules = akeyless.models.saml_access_rules_defines_access_rules_specific_to_saml_authentication_method/.SAMLAccessRules defines access rules specific to SAML authentication method.(
                                bound_attributes = [
                                    akeyless.models.saml_attribute_defines_an_attribute_of_saml_authentication/.SAMLAttribute defines an attribute of SAML authentication.(
                                        name = '0', )
                                    ], 
                                idp_metadata_url = '0', 
                                idp_metadata_xml = '0', ), 
                            universal_identity_access_rules = akeyless.models.universal_identity_access_rules_contains_access_rules_specific_to_universal_identity/.UniversalIdentityAccessRules contains access rules specific to Universal Identity.(
                                deny_inheritance = True, 
                                deny_rotate = True, 
                                ttl = 56, ), ), 
                        account_id = '0', 
                        auth_method_access_id = '0', 
                        auth_method_name = '0', 
                        auth_method_roles_assoc = [
                            akeyless.models.auth_method_role_association.AuthMethodRoleAssociation(
                                assoc_id = '0', 
                                auth_method_sub_claims = {
                                    'key' : [
                                        '0'
                                        ]
                                    }, 
                                rules = akeyless.models.rules_are_a_part_of_akeyless_rbac/.Rules are a part of AKEYLESS RBAC.(
                                    admin = True, 
                                    path_rules = [
                                        akeyless.models.path_rule_is_a_single_rule_used_in_akeyless_rbac/.PathRule is a single rule used in AKEYLESS RBAC.(
                                            capabilities = [
                                                '0'
                                                ], 
                                            path = '0', 
                                            type = '0', )
                                        ], ), )
                            ], 
                        client_permissions = [
                            '0'
                            ], )
                    ], 
                next_page = '0'
            )
        else :
            return ListAuthMethodsOutput(
        )

    def testListAuthMethodsOutput(self):
        """Test ListAuthMethodsOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'add_tag': 'list[str]',
        'api_id': 'str',
        'api_key': 'str',
        'auto_rotate': 'str',
        'custom_payload': 'str',
        'delete_protection': 'str',
        'gcp_key': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'key': 'str',
        'name': 'str',
        'new_metadata': 'str',
        'new_name': 'str',
        'new_version': 'bool',
        'rm_tag': 'list[str]',
        'rotated_password': 'str',
        'rotated_username': 'str',
        'rotation_hour': 'int',
        'rotation_interval': 'str',
        'rotator_creds_type': 'str',
        'token': 'str',
        'type': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'add_tag': 'add-tag',
        'api_id': 'api-id',
        'api_key': 'api-key',
        'auto_rotate': 'auto-rotate',
        'custom_payload': 'custom-payload',
        'delete_protection': 'delete_protection',
        'gcp_key': 'gcp-key',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'key': 'key',
        'name': 'name',
        'new_metadata': 'new-metadata',
        'new_name': 'new-name',
        'new_version': 'new-version',
        'rm_tag': 'rm-tag',
        'rotated_password': 'rotated-password',
        'rotated_username': 'rotated-username',
        'rotation_hour': 'rotation-hour',
        'rotation_interval': 'rotation-interval',
        'rotator_creds_type': 'rotator-creds-type',
        'token': 'token',
        'type': 'type',
        'uid_token': 'uid-token'
    }

    def __init__(self, add_tag=None, api_id=None, api_key=None, auto_rotate=None, custom_payload=None, delete_protection=None, gcp_key=None, json=None, keep_prev_version=None, key=None, name=None, new_metadata='default_metadata', new_name=None, new_version=None, rm_tag=None, rotated_password=None, rotated_username=None, rotation_hour=0, rotation_interval=None, rotator_creds_type=None, token=None, type=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._add_tag = None
        self._api_id = None
        self._api_key = None
        self._auto_rotate = None
        self._custom_payload = None
        self._delete_protection = None
        self._gcp_key = None
        self._json = None
        self._keep_prev_version = None
        self._key = None
        self._name = None
        self._new_metadata = None
        self._new_name = None
        self._new_version = None
        self._rm_tag = None
        self._rotated_password = None
        self._rotated_username = None
        self._rotation_hour = None
        self._rotation_interval = None
        self._rotator_creds_type = None
        self._token = None
        self._type = None
        self._uid_token = None
        self.discriminator = None

        if add_tag is not None:
            self.add_tag = add_tag
        if api_id is not None:
            self.api_id = api_id
        if api_key is not None:
            self.api_key = api_key
        if auto_rotate is not None:
            self.auto_rotate = auto_rotate
        if custom_payload is not None:
            self.custom_payload = custom_payload
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if gcp_key is not None:
            self.gcp_key = gcp_key
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        if key is not None:
            self.key = key
        self.name = name
        if new_metadata is not None:
            self.new_metadata = new_metadata
        if new_name is not None:
            self.new_name = new_name
        if new_version is not None:
            self.new_version = new_version
        if rm_tag is not None:
            self.rm_tag = rm_tag
        if rotated_password is not None:
            self.rotated_password = rotated_password
        if rotated_username is not None:
            self.rotated_username = rotated_username
        if rotation_hour is not None:
            self.rotation_hour = rotation_hour
        if rotation_interval is not None:
            self.rotation_interval = rotation_interval
        if rotator_creds_type is not None:
            self.rotator_creds_type = rotator_creds_type
        if token is not None:
            self.token = token
        self.type = type
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def add_tag(self):
        """Gets the add_tag of this GatewayUpdateItem.  # noqa: E501

        List of the new tags that will be attached to this item  # noqa: E501

        :return: The add_tag of this GatewayUpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tag

    @add_tag.setter
    def add_tag(self, add_tag):
        """Sets the add_tag of this GatewayUpdateItem.

        List of the new tags that will be attached to this item  # noqa: E501

        :param add_tag: The add_tag of this GatewayUpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._add_tag = add_tag

    @property
    def api_id(self):
        """Gets the api_id of this GatewayUpdateItem.  # noqa: E501


        :return: The api_id of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._api_id

    @api_id.setter
    def api_id(self, api_id):
        """Sets the api_id of this GatewayUpdateItem.


        :param api_id: The api_id of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._api_id = api_id

    @property
    def api_key(self):
        """Gets the api_key of this GatewayUpdateItem.  # noqa: E501


        :return: The api_key of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this GatewayUpdateItem.


        :param api_key: The api_key of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def auto_rotate(self):
        """Gets the auto_rotate of this GatewayUpdateItem.  # noqa: E501

        Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation  # noqa: E501

        :return: The auto_rotate of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._auto_rotate

    @auto_rotate.setter
    def auto_rotate(self, auto_rotate):
        """Sets the auto_rotate of this GatewayUpdateItem.

        Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation  # noqa: E501

        :param auto_rotate: The auto_rotate of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._auto_rotate = auto_rotate

    @property
    def custom_payload(self):
        """Gets the custom_payload of this GatewayUpdateItem.  # noqa: E501


        :return: The custom_payload of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._custom_payload

    @custom_payload.setter
    def custom_payload(self, custom_payload):
        """Sets the custom_payload of this GatewayUpdateItem.


        :param custom_payload: The custom_payload of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._custom_payload = custom_payload

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateItem.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateItem.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def gcp_key(self):
        """Gets the gcp_key of this GatewayUpdateItem.  # noqa: E501

        Base64-encoded service account private key text  # noqa: E501

        :return: The gcp_key of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._gcp_key

    @gcp_key.setter
    def gcp_key(self, gcp_key):
        """Sets the gcp_key of this GatewayUpdateItem.

        Base64-encoded service account private key text  # noqa: E501

        :param gcp_key: The gcp_key of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._gcp_key = gcp_key

    @property
    def json(self):
        """Gets the json of this GatewayUpdateItem.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateItem.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateItem.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this GatewayUpdateItem.  # noqa: E501


        :return: The keep_prev_version of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this GatewayUpdateItem.


        :param keep_prev_version: The keep_prev_version of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def key(self):
        """Gets the key of this GatewayUpdateItem.  # noqa: E501

        The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this GatewayUpdateItem.

        The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this GatewayUpdateItem.  # noqa: E501

        Item name  # noqa: E501

        :return: The name of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateItem.

        Item name  # noqa: E501

        :param name: The name of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_metadata(self):
        """Gets the new_metadata of this GatewayUpdateItem.  # noqa: E501

        New item metadata  # noqa: E501

        :return: The new_metadata of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._new_metadata

    @new_metadata.setter
    def new_metadata(self, new_metadata):
        """Sets the new_metadata of this GatewayUpdateItem.

        New item metadata  # noqa: E501

        :param new_metadata: The new_metadata of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._new_metadata = new_metadata

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateItem.  # noqa: E501

        New item name  # noqa: E501

        :return: The new_name of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateItem.

        New item name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def new_version(self):
        """Gets the new_version of this GatewayUpdateItem.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The new_version of this GatewayUpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._new_version

    @new_version.setter
    def new_version(self, new_version):
        """Sets the new_version of this GatewayUpdateItem.

        Deprecated  # noqa: E501

        :param new_version: The new_version of this GatewayUpdateItem.  # noqa: E501
        :type: bool
        """

        self._new_version = new_version

    @property
    def rm_tag(self):
        """Gets the rm_tag of this GatewayUpdateItem.  # noqa: E501

        List of the existent tags that will be removed from this item  # noqa: E501

        :return: The rm_tag of this GatewayUpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._rm_tag

    @rm_tag.setter
    def rm_tag(self, rm_tag):
        """Sets the rm_tag of this GatewayUpdateItem.

        List of the existent tags that will be removed from this item  # noqa: E501

        :param rm_tag: The rm_tag of this GatewayUpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._rm_tag = rm_tag

    @property
    def rotated_password(self):
        """Gets the rotated_password of this GatewayUpdateItem.  # noqa: E501


        :return: The rotated_password of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._rotated_password

    @rotated_password.setter
    def rotated_password(self, rotated_password):
        """Sets the rotated_password of this GatewayUpdateItem.


        :param rotated_password: The rotated_password of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._rotated_password = rotated_password

    @property
    def rotated_username(self):
        """Gets the rotated_username of this GatewayUpdateItem.  # noqa: E501


        :return: The rotated_username of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._rotated_username

    @rotated_username.setter
    def rotated_username(self, rotated_username):
        """Sets the rotated_username of this GatewayUpdateItem.


        :param rotated_username: The rotated_username of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._rotated_username = rotated_username

    @property
    def rotation_hour(self):
        """Gets the rotation_hour of this GatewayUpdateItem.  # noqa: E501

        The Rotation Hour  # noqa: E501

        :return: The rotation_hour of this GatewayUpdateItem.  # noqa: E501
        :rtype: int
        """
        return self._rotation_hour

    @rotation_hour.setter
    def rotation_hour(self, rotation_hour):
        """Sets the rotation_hour of this GatewayUpdateItem.

        The Rotation Hour  # noqa: E501

        :param rotation_hour: The rotation_hour of this GatewayUpdateItem.  # noqa: E501
        :type: int
        """

        self._rotation_hour = rotation_hour

    @property
    def rotation_interval(self):
        """Gets the rotation_interval of this GatewayUpdateItem.  # noqa: E501

        The number of days to wait between every automatic key rotation (1-365)  # noqa: E501

        :return: The rotation_interval of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._rotation_interval

    @rotation_interval.setter
    def rotation_interval(self, rotation_interval):
        """Sets the rotation_interval of this GatewayUpdateItem.

        The number of days to wait between every automatic key rotation (1-365)  # noqa: E501

        :param rotation_interval: The rotation_interval of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._rotation_interval = rotation_interval

    @property
    def rotator_creds_type(self):
        """Gets the rotator_creds_type of this GatewayUpdateItem.  # noqa: E501

        The rotation credentials type  # noqa: E501

        :return: The rotator_creds_type of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._rotator_creds_type

    @rotator_creds_type.setter
    def rotator_creds_type(self, rotator_creds_type):
        """Sets the rotator_creds_type of this GatewayUpdateItem.

        The rotation credentials type  # noqa: E501

        :param rotator_creds_type: The rotator_creds_type of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._rotator_creds_type = rotator_creds_type

    @property
    def token(self):
        """Gets the token of this GatewayUpdateItem.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateItem.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def type(self):
        """Gets the type of this GatewayUpdateItem.  # noqa: E501

        Item type  # noqa: E501

        :return: The type of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GatewayUpdateItem.

        Item type  # noqa: E501

        :param type: The type of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateItem.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateItem.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateItem.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.item import Item  # noqa: E501
from akeyless.rest import ApiException

class TestItem(unittest.TestCase):
    """Item unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Item
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.item.Item()  # noqa: E501
        if include_optional :
            return Item(
                auto_rotate = True, 
                cert_issuer_signer_key_name = '0', 
                certificate_issue_details = akeyless.models.certificate_issue_info_defines_certificate_issuer_info/.CertificateIssueInfo defines Certificate Issuer info.(
                    cert_issuer_type = '0', 
                    max_ttl = 56, 
                    pki_cert_issuer_details = akeyless.models.pki_certificate_issue_details_defines_pki_certificate_details/.PKICertificateIssueDetails defines PKI certificate details.(
                        allow_any_name = True, 
                        allow_subdomains = True, 
                        allowed_domains_list = [
                            '0'
                            ], 
                        allowed_uri_sans = [
                            '0'
                            ], 
                        client_flag = True, 
                        code_signing_flag = True, 
                        country = [
                            '0'
                            ], 
                        enforce_hostnames = True, 
                        key_bits = 56, 
                        key_type = '0', 
                        key_usage_list = [
                            '0'
                            ], 
                        locality = [
                            '0'
                            ], 
                        not_before_duration = 56, 
                        organization_list = [
                            '0'
                            ], 
                        organization_unit_list = [
                            '0'
                            ], 
                        postal_code = [
                            '0'
                            ], 
                        province = [
                            '0'
                            ], 
                        require_cn = True, 
                        server_flag = True, 
                        street_address = [
                            '0'
                            ], ), 
                    ssh_cert_issuer_details = akeyless.models.ssh_certificate_issue_details_defines_ssh_certificate_details/.SSHCertificateIssueDetails defines SSH certificate details.(
                        allowed_domains = [
                            '0'
                            ], 
                        allowed_user_key_lengths = {
                            'key' : 56
                            }, 
                        allowed_users = [
                            '0'
                            ], 
                        cert_type = 56, 
                        critical_options = {
                            'key' : '0'
                            }, 
                        extensions = {
                            'key' : '0'
                            }, 
                        principals = [
                            '0'
                            ], 
                        static_key_id = '0', ), ), 
                certificates = '0', 
                client_permissions = [
                    '0'
                    ], 
                deletion_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                is_enabled = True, 
                item_general_info = akeyless.models.item_general_info_defines_item_general_info/.ItemGeneralInfo defines item general info.(
                    cert_issue_details = akeyless.models.certificate_issue_info_defines_certificate_issuer_info/.CertificateIssueInfo defines Certificate Issuer info.(
                        cert_issuer_type = '0', 
                        max_ttl = 56, 
                        pki_cert_issuer_details = akeyless.models.pki_certificate_issue_details_defines_pki_certificate_details/.PKICertificateIssueDetails defines PKI certificate details.(
                            allow_any_name = True, 
                            allow_subdomains = True, 
                            allowed_domains_list = [
                                '0'
                                ], 
                            allowed_uri_sans = [
                                '0'
                                ], 
                            client_flag = True, 
                            code_signing_flag = True, 
                            country = [
                                '0'
                                ], 
                            enforce_hostnames = True, 
                            key_bits = 56, 
                            key_type = '0', 
                            key_usage_list = [
                                '0'
                                ], 
                            locality = [
                                '0'
                                ], 
                            not_before_duration = 56, 
                            organization_list = [
                                '0'
                                ], 
                            organization_unit_list = [
                                '0'
                                ], 
                            postal_code = [
                                '0'
                                ], 
                            province = [
                                '0'
                                ], 
                            require_cn = True, 
                            server_flag = True, 
                            street_address = [
                                '0'
                                ], ), 
                        ssh_cert_issuer_details = akeyless.models.ssh_certificate_issue_details_defines_ssh_certificate_details/.SSHCertificateIssueDetails defines SSH certificate details.(
                            allowed_domains = [
                                '0'
                                ], 
                            allowed_user_key_lengths = {
                                'key' : 56
                                }, 
                            allowed_users = [
                                '0'
                                ], 
                            cert_type = 56, 
                            critical_options = {
                                'key' : '0'
                                }, 
                            extensions = {
                                'key' : '0'
                                }, 
                            principals = [
                                '0'
                                ], 
                            static_key_id = '0', ), ), 
                    dynamic_secret_producer_details = akeyless.models.dynamic_secret_producer_info.DynamicSecretProducerInfo(
                        producer_status = '0', 
                        producer_type = '0', ), ), 
                item_metadata = '0', 
                item_name = '0', 
                item_size = 56, 
                item_state = '0', 
                item_tags = [
                    '0'
                    ], 
                item_type = '0', 
                item_versions = [
                    akeyless.models.item_version_describes_an_item_version_in_akeyless/.ItemVersion describes an item version in AKEYLESS.(
                        creation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        deletion_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        item_version_state = '0', 
                        protection_key_name = '0', 
                        version = 56, 
                        with_customer_fragment = True, )
                    ], 
                last_version = 56, 
                next_rotation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                producer_status = '0', 
                protection_key_name = '0', 
                public_value = '0', 
                rotation_interval = 56, 
                with_customer_fragment = True
            )
        else :
            return Item(
        )

    def testItem(self):
        """Test Item"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayMigratePersonalItems(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_1password_email': 'str',
        '_1password_password': 'str',
        '_1password_secret_key': 'str',
        '_1password_url': 'str',
        '_1password_vaults': 'list[str]',
        'json': 'bool',
        'protection_key': 'str',
        'target_location': 'str',
        'token': 'str',
        'type': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        '_1password_email': '1password-email',
        '_1password_password': '1password-password',
        '_1password_secret_key': '1password-secret-key',
        '_1password_url': '1password-url',
        '_1password_vaults': '1password-vaults',
        'json': 'json',
        'protection_key': 'protection-key',
        'target_location': 'target-location',
        'token': 'token',
        'type': 'type',
        'uid_token': 'uid-token'
    }

    def __init__(self, _1password_email=None, _1password_password=None, _1password_secret_key=None, _1password_url=None, _1password_vaults=None, json=None, protection_key=None, target_location=None, token=None, type='1password', uid_token=None, local_vars_configuration=None):  # noqa: E501
        """GatewayMigratePersonalItems - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__1password_email = None
        self.__1password_password = None
        self.__1password_secret_key = None
        self.__1password_url = None
        self.__1password_vaults = None
        self._json = None
        self._protection_key = None
        self._target_location = None
        self._token = None
        self._type = None
        self._uid_token = None
        self.discriminator = None

        if _1password_email is not None:
            self._1password_email = _1password_email
        if _1password_password is not None:
            self._1password_password = _1password_password
        if _1password_secret_key is not None:
            self._1password_secret_key = _1password_secret_key
        if _1password_url is not None:
            self._1password_url = _1password_url
        if _1password_vaults is not None:
            self._1password_vaults = _1password_vaults
        if json is not None:
            self.json = json
        if protection_key is not None:
            self.protection_key = protection_key
        if target_location is not None:
            self.target_location = target_location
        if token is not None:
            self.token = token
        if type is not None:
            self.type = type
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def _1password_email(self):
        """Gets the _1password_email of this GatewayMigratePersonalItems.  # noqa: E501

        1Password user email to connect to the API  # noqa: E501

        :return: The _1password_email of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self.__1password_email

    @_1password_email.setter
    def _1password_email(self, _1password_email):
        """Sets the _1password_email of this GatewayMigratePersonalItems.

        1Password user email to connect to the API  # noqa: E501

        :param _1password_email: The _1password_email of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self.__1password_email = _1password_email

    @property
    def _1password_password(self):
        """Gets the _1password_password of this GatewayMigratePersonalItems.  # noqa: E501

        1Password user password to connect to the API  # noqa: E501

        :return: The _1password_password of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self.__1password_password

    @_1password_password.setter
    def _1password_password(self, _1password_password):
        """Sets the _1password_password of this GatewayMigratePersonalItems.

        1Password user password to connect to the API  # noqa: E501

        :param _1password_password: The _1password_password of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self.__1password_password = _1password_password

    @property
    def _1password_secret_key(self):
        """Gets the _1password_secret_key of this GatewayMigratePersonalItems.  # noqa: E501

        1Password user secret key to connect to the API  # noqa: E501

        :return: The _1password_secret_key of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self.__1password_secret_key

    @_1password_secret_key.setter
    def _1password_secret_key(self, _1password_secret_key):
        """Sets the _1password_secret_key of this GatewayMigratePersonalItems.

        1Password user secret key to connect to the API  # noqa: E501

        :param _1password_secret_key: The _1password_secret_key of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self.__1password_secret_key = _1password_secret_key

    @property
    def _1password_url(self):
        """Gets the _1password_url of this GatewayMigratePersonalItems.  # noqa: E501

        1Password api container url  # noqa: E501

        :return: The _1password_url of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self.__1password_url

    @_1password_url.setter
    def _1password_url(self, _1password_url):
        """Sets the _1password_url of this GatewayMigratePersonalItems.

        1Password api container url  # noqa: E501

        :param _1password_url: The _1password_url of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self.__1password_url = _1password_url

    @property
    def _1password_vaults(self):
        """Gets the _1password_vaults of this GatewayMigratePersonalItems.  # noqa: E501

        1Password list of vault to get the items from  # noqa: E501

        :return: The _1password_vaults of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: list[str]
        """
        return self.__1password_vaults

    @_1password_vaults.setter
    def _1password_vaults(self, _1password_vaults):
        """Sets the _1password_vaults of this GatewayMigratePersonalItems.

        1Password list of vault to get the items from  # noqa: E501

        :param _1password_vaults: The _1password_vaults of this GatewayMigratePersonalItems.  # noqa: E501
        :type: list[str]
        """

        self.__1password_vaults = _1password_vaults

    @property
    def json(self):
        """Gets the json of this GatewayMigratePersonalItems.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayMigratePersonalItems.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayMigratePersonalItems.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def protection_key(self):
        """Gets the protection_key of this GatewayMigratePersonalItems.  # noqa: E501

        The name of a key that used to encrypt the secret value  # noqa: E501

        :return: The protection_key of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this GatewayMigratePersonalItems.

        The name of a key that used to encrypt the secret value  # noqa: E501

        :param protection_key: The protection_key of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def target_location(self):
        """Gets the target_location of this GatewayMigratePersonalItems.  # noqa: E501

        Target location in your Akeyless personal folder for migrated secrets  # noqa: E501

        :return: The target_location of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self._target_location

    @target_location.setter
    def target_location(self, target_location):
        """Sets the target_location of this GatewayMigratePersonalItems.

        Target location in your Akeyless personal folder for migrated secrets  # noqa: E501

        :param target_location: The target_location of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self._target_location = target_location

    @property
    def token(self):
        """Gets the token of this GatewayMigratePersonalItems.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayMigratePersonalItems.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def type(self):
        """Gets the type of this GatewayMigratePersonalItems.  # noqa: E501

        Migration type for now only 1password.  # noqa: E501

        :return: The type of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GatewayMigratePersonalItems.

        Migration type for now only 1password.  # noqa: E501

        :param type: The type of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayMigratePersonalItems.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayMigratePersonalItems.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayMigratePersonalItems.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayMigratePersonalItems.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayMigratePersonalItems):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayMigratePersonalItems):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.k8_s_auths_config_part import K8SAuthsConfigPart  # noqa: E501
from akeyless.rest import ApiException

class TestK8SAuthsConfigPart(unittest.TestCase):
    """K8SAuthsConfigPart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test K8SAuthsConfigPart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.k8_s_auths_config_part.K8SAuthsConfigPart()  # noqa: E501
        if include_optional :
            return K8SAuthsConfigPart(
                k8s_auths = [
                    akeyless.models.k8_s_auth.K8SAuth(
                        am_token_expiration = 56, 
                        auth_method_access_id = '0', 
                        auth_method_prv_key_pem = '0', 
                        disable_iss_validation = True, 
                        id = '0', 
                        k8s_ca_cert = '0', 
                        k8s_host = '0', 
                        k8s_issuer = '0', 
                        k8s_pub_keys_pem = [
                            '0'
                            ], 
                        k8s_token_reviewer_jwt = '0', 
                        name = '0', 
                        protection_key = '0', 
                        use_local_ca_jwt = True, )
                    ]
            )
        else :
            return K8SAuthsConfigPart(
        )

    def testK8SAuthsConfigPart(self):
        """Test K8SAuthsConfigPart"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateRDPTargetDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admin_name': 'str',
        'admin_pwd': 'str',
        'host_name': 'str',
        'host_port': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'name': 'str',
        'new_version': 'bool',
        'protection_key': 'str',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'admin_name': 'admin_name',
        'admin_pwd': 'admin_pwd',
        'host_name': 'host_name',
        'host_port': 'host_port',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'name': 'name',
        'new_version': 'new-version',
        'protection_key': 'protection_key',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, admin_name=None, admin_pwd=None, host_name=None, host_port=None, json=None, keep_prev_version=None, name=None, new_version=None, protection_key=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UpdateRDPTargetDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admin_name = None
        self._admin_pwd = None
        self._host_name = None
        self._host_port = None
        self._json = None
        self._keep_prev_version = None
        self._name = None
        self._new_version = None
        self._protection_key = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if admin_name is not None:
            self.admin_name = admin_name
        if admin_pwd is not None:
            self.admin_pwd = admin_pwd
        if host_name is not None:
            self.host_name = host_name
        if host_port is not None:
            self.host_port = host_port
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        self.name = name
        if new_version is not None:
            self.new_version = new_version
        if protection_key is not None:
            self.protection_key = protection_key
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def admin_name(self):
        """Gets the admin_name of this UpdateRDPTargetDetails.  # noqa: E501


        :return: The admin_name of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._admin_name

    @admin_name.setter
    def admin_name(self, admin_name):
        """Sets the admin_name of this UpdateRDPTargetDetails.


        :param admin_name: The admin_name of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._admin_name = admin_name

    @property
    def admin_pwd(self):
        """Gets the admin_pwd of this UpdateRDPTargetDetails.  # noqa: E501


        :return: The admin_pwd of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._admin_pwd

    @admin_pwd.setter
    def admin_pwd(self, admin_pwd):
        """Sets the admin_pwd of this UpdateRDPTargetDetails.


        :param admin_pwd: The admin_pwd of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._admin_pwd = admin_pwd

    @property
    def host_name(self):
        """Gets the host_name of this UpdateRDPTargetDetails.  # noqa: E501


        :return: The host_name of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this UpdateRDPTargetDetails.


        :param host_name: The host_name of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def host_port(self):
        """Gets the host_port of this UpdateRDPTargetDetails.  # noqa: E501


        :return: The host_port of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._host_port

    @host_port.setter
    def host_port(self, host_port):
        """Sets the host_port of this UpdateRDPTargetDetails.


        :param host_port: The host_port of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._host_port = host_port

    @property
    def json(self):
        """Gets the json of this UpdateRDPTargetDetails.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateRDPTargetDetails.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateRDPTargetDetails.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateRDPTargetDetails.  # noqa: E501


        :return: The keep_prev_version of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateRDPTargetDetails.


        :param keep_prev_version: The keep_prev_version of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def name(self):
        """Gets the name of this UpdateRDPTargetDetails.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateRDPTargetDetails.

        Target name  # noqa: E501

        :param name: The name of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_version(self):
        """Gets the new_version of this UpdateRDPTargetDetails.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The new_version of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: bool
        """
        return self._new_version

    @new_version.setter
    def new_version(self, new_version):
        """Sets the new_version of this UpdateRDPTargetDetails.

        Deprecated  # noqa: E501

        :param new_version: The new_version of this UpdateRDPTargetDetails.  # noqa: E501
        :type: bool
        """

        self._new_version = new_version

    @property
    def protection_key(self):
        """Gets the protection_key of this UpdateRDPTargetDetails.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The protection_key of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this UpdateRDPTargetDetails.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param protection_key: The protection_key of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def token(self):
        """Gets the token of this UpdateRDPTargetDetails.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateRDPTargetDetails.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateRDPTargetDetails.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateRDPTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateRDPTargetDetails.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateRDPTargetDetails.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRDPTargetDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateRDPTargetDetails):
            return True

        return self.to_dict() != other.to_dict()
